SystemOrganization addCategory: #ConfigurationOfScriptManager!

Object subclass: #ConfigurationOfScriptManager
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfScriptManager'!

!ConfigurationOfScriptManager class methodsFor: 'private' stamp: 'tbn 1/26/2010 09:50'!
bootstrapPackage: aString from: aPath 
	| repository version |
	repository := MCHttpRepository
				location: aPath
				user: ''
				password: ''.
	repository
		versionReaderForFileNamed: aString , '.mcz'
		do: [:reader | 
			version := reader version.
			version load.
			version workingCopy repositoryGroup addRepository: repository]! !

!ConfigurationOfScriptManager class methodsFor: 'private' stamp: 'tbn 1/26/2010 09:50'!
ensureMetacello
	"Bootstrap Gofer (if necessary), bootstrap ConfigurationOfMetacello (using old Gofer API), then load the latest 
	version of Metacello itself."

	Smalltalk at: #MetacelloProject ifAbsent: [
		Smalltalk at: #Gofer ifAbsent: [
			"Current version of Gofer from which to bootstrap - as of 1.0-beta.21"
			self bootstrapPackage: 'Gofer-Core-lr.115' from: 'http://seaside.gemstone.com/ss/metacello' ].
		Smalltalk at: #Gofer ifPresent: [:goferClass | | gofer |
			gofer := goferClass new
				url: 'http://seaside.gemstone.com/ss/metacello';
				yourself.
			[ gofer addPackage: 'ConfigurationOfMetacello' ] on: Warning do: [:ex | ex resume ].
			gofer load ].
		"load 'default' group of Metacello"
		(Smalltalk at: #ConfigurationOfMetacello) perform: #load ]! !

!ConfigurationOfScriptManager class methodsFor: 'metacello tool support' stamp: 'tbn 1/26/2010 09:50'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfScriptManager class methodsFor: 'metacello tool support' stamp: 'tbn 1/26/2010 09:50'!
lastMetacelloVersionLoad
	"Answer the last version loaded and the list of packages loaded for that version."

	LastVersionLoad == nil ifTrue: [ LastVersionLoad := nil -> 'default' ].
	^LastVersionLoad! !

!ConfigurationOfScriptManager class methodsFor: 'loading' stamp: 'tbn 1/26/2010 09:50'!
load
	"self load"

	^self project latestVersion load! !

!ConfigurationOfScriptManager class methodsFor: 'metacello tool support' stamp: 'tbn 1/26/2010 09:50'!
metacelloVersion: versionString loads: anArrayOrString
	"Stash the last version loaded and the list of packages loaded for that version. The list
	 of packages will be used by the tools when doing 'Load Package Version'"

	LastVersionLoad := versionString -> anArrayOrString! !

!ConfigurationOfScriptManager class methodsFor: 'accessing' stamp: 'tbn 1/26/2010 09:50'!
project

	^self new project! !

!ConfigurationOfScriptManager methodsFor: 'baselines' stamp: 'TorstenBergmann 3/12/2013 21:01'!
baseline10: spec 
	<version: '1.0-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://smalltalkhub.com/mc/TorstenBergmann/ScriptManager/main'.	
		spec 
			package: 'ScriptManager-Core'.
		spec
			group: 'default' with: #('Core');
			group: 'Core' with: #('ScriptManager-Core')].! !

!ConfigurationOfScriptManager methodsFor: 'baselines' stamp: 'TorstenBergmann 3/12/2013 21:01'!
baseline11: spec 
	<version: '1.1-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://smalltalkhub.com/mc/TorstenBergmann/ScriptManager/main'.	
		spec 
			package: 'ScriptManager-Core';
			package: 'ScriptManager-Help'.
		spec
			group: 'default' with: #('Core');
			group: 'Core' with: #('ScriptManager-Core')].! !

!ConfigurationOfScriptManager methodsFor: 'accessing' stamp: 'tbn 1/26/2010 09:50'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		self class ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear. "change to #atomic if desired"
		project ]! !

!ConfigurationOfScriptManager methodsFor: 'symbolic versions' stamp: 'tbn 7/2/2013 15:53'!
stable: spec 
	<symbolicVersion: #stable>
	
	spec for: #'pharo1.1.x' version: '1.2'. 
	spec for: #'pharo1.2.x' version: '1.2'. 
	spec for: #'pharo1.3.x' version: '1.3'.
	spec for: #'pharo1.4.x' version: '1.4'.
	spec for: #'pharo2.0.x' version: '1.6'.
	spec for: #'pharo3.0.x' version: '1.6'.
	! !

!ConfigurationOfScriptManager methodsFor: 'versions' stamp: 'tbn 5/13/2010 00:58'!
version10: spec 
	<version: '1.0' imports: #('1.0-baseline') >
	
	spec for: #common do: [
		spec blessing: #release.
		spec 
			package: 'ScriptManager-Core' with: 'ScriptManager-Core-tbn.9'].! !

!ConfigurationOfScriptManager methodsFor: 'versions' stamp: 'tbn 5/15/2010 17:31'!
version11: spec 
	<version: '1.1' imports: #('1.0-baseline') >
	
	spec for: #common do: [
		spec blessing: #release.
		spec 
			package: 'ScriptManager-Core' with: 'ScriptManager-Core-tbn.11'].! !

!ConfigurationOfScriptManager methodsFor: 'versions' stamp: 'GuillermoPolito 3/13/2011 16:46'!
version12: spec 
	<version: '1.2' imports: #('1.1-baseline') >
	
	spec for: #common do: [
		spec blessing: #release.
		spec 
			package: 'ScriptManager-Core' with: 'ScriptManager-Core-tbn.11';
			package: 'ScriptManager-Help' with: 'ScriptManager-Help-tbn.1'].! !

!ConfigurationOfScriptManager methodsFor: 'versions' stamp: 'MarianoMartinezPeck 7/1/2011 20:15'!
version13: spec 
	<version: '1.3' imports: #('1.1-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec 
			package: 'ScriptManager-Core' with: 'ScriptManager-Core-tbn.13';
			package: 'ScriptManager-Help' with: 'ScriptManager-Help-tbn.1'].! !

!ConfigurationOfScriptManager methodsFor: 'versions' stamp: 'GuillermoPolito 4/26/2012 22:39'!
version14: spec 
	<version: '1.4' imports: #('1.1-baseline') >
	
	spec for: #common do: [
		spec blessing: #release.
		spec 
			package: 'ScriptManager-Core' with: 'ScriptManager-Core-GuillermoPolito.15';
			package: 'ScriptManager-Help' with: 'ScriptManager-Help-tbn.1']! !

!ConfigurationOfScriptManager methodsFor: 'versions' stamp: 'tbn 6/20/2012 11:17'!
version15: spec 
	<version: '1.5' imports: #('1.1-baseline') >
	
	spec for: #common do: [
		spec blessing: #release.
		spec 
			package: 'ScriptManager-Core' with: 'ScriptManager-Core-tbn.17';
			package: 'ScriptManager-Help' with: 'ScriptManager-Help-tbn.1']! !

!ConfigurationOfScriptManager methodsFor: 'versions' stamp: 'TorstenBergmann 1/1/2013 21:16'!
version16: spec 
	<version: '1.6' imports: #('1.1-baseline') >
	
	spec for: #common do: [
		spec blessing: #release.
		spec 
			package: 'ScriptManager-Core' with: 'ScriptManager-Core-TorstenBergmann.19';
			package: 'ScriptManager-Help' with: 'ScriptManager-Help-tbn.1']! !
